=====
Usage
=====

To use ML Launchpad in a project::

    import mllaunchpad

Have a look at the examples provided in `mllaunchpad's GitHub repository`_
(`download <https://minhaskamal.github.io/DownGit/#/home?url=https://github.com/schuderer/mllaunchpad/tree/master/examples>`_).

_`mllaunchpad's GitHub repository`: https://github.com/schuderer/mllaunchpad/
